=============
API reference
=============

Plotting functions
==================

Primary functions.

.. autofunction:: mplhep.histplot

.. autofunction:: mplhep.hist2dplot

.. # List all modules when appropriately privatized
   .. automodule:: mplhep.plot
      :members:

Experiment label helpers
========================

Experiment specific helpers

.. autofunction:: mplhep.cms.lumitext

.. autofunction:: mplhep.cms.text

.. autofunction:: mplhep.cms.label

.. autofunction:: mplhep.atlas.text

.. autofunction:: mplhep.atlas.label

.. autofunction:: mplhep.lhcb.text

.. autofunction:: mplhep.lhcb.label


Axes helpers
============

Use all helpers together

.. autofunction:: mplhep.mpl_magic

or one by one.

.. autofunction:: mplhep.plot.ylow

.. autofunction:: mplhep.plot.yscale_legend

.. autofunction:: mplhep.plot.yscale_text


Figure helpers
==============

.. autofunction:: mplhep.append_axes

.. autofunction:: mplhep.box_aspect

.. autofunction:: mplhep.make_square_add_cbar

.. autofunction:: mplhep.rescale_to_axessize

Legend helpers
==============

.. autofunction:: mplhep.sort_legend()


Styles
==================

To be included, when I figure out how to sphinx dictionaries in.
